% DEST.M performs local Whittle estimation of the memory
%	parameter d. This program calls two other programs,
%   ewhittle.m and whittle.m.
% 
% 
%				Katsumi Shimotsu, February 2003
%_______________________________________________________________

clear;

d = 0.4;            % the value of d

u = randn(500,1);	% In this example, we generate 500 observations of an I(d) process.
x = fracdiff(u,-d); % Replace this part with your data.

n = length(x);
x2 = dmtrend(x);	% demeaned & detrended data

m = fix(n^0.6);		% m is the number of frequencies used in estimation.

options = optimset('fminbnd');

dw = fminbnd('whittle',-1,3,options,x,m);		% LW estimate
ew1 = fminbnd('ewhittle',-2,4,options,x,m,0);	% ELW estimate
ew2 = fminbnd('ewhittle',-2,4,options,x,m,1);	% FELW estimate
ew3 = fminbnd('ewhittle',-2,4,options,x2,m,1);	% FELW w/ detrending
felw1 = felw2st(x,m,3,10);						% 2stage FELW 
felw2 = felw2st(x2,m,3,10);						% 2stage FELW w/ detrending
 
fprintf(1,'Number of observations     %7i \n', n);
fprintf(1,'Number of frequencies used %7i \n\n', m);
fprintf(1,'Estimate of d: LW estimator                                %7.5f  \n', dw);
fprintf(1,'Estimate of d: exact LW estimator                          %7.5f  \n', ew1);
fprintf(1,'Estimate of d: feasible ELW estimator                      %7.5f  \n', ew2);
fprintf(1,'Estimate of d: feasible ELW estimator with detrending      %7.5f  \n', ew3);
fprintf(1,'Estimate of d: 2-step feasible ELW estimator               %7.5f  \n', felw1);
fprintf(1,'Estimate of d: 2-step feasible ELW estimator w/ detrending %7.5f  \n', felw2);
